@@ -42,5 +42,9 @@ def from_load(load):
 	trans_data['origin_pallets_required'] = load.origin_pallets_required
 	trans_data['destination_pallets_required'] = load.destination_pallets_required
 	trans_data['hazmat'] = load.hazmat
+	trans_data['origin_location_id'] = load.origin_location_id
+	trans_data['origin_location_name'] = load.origin_location_name
+	trans_data['destination_location_id'] = load.destination_location_id
+	trans_data['destination_location_name'] = load.destination_location_name
 	transaction = Transaction(**trans_data)
 	return transaction
