@@ -95,3 +95,7 @@ class Transaction:
     min_temperature: float = field(default=None)
     origin_pallets_required: bool = field(default=False)
     destination_pallets_required: bool = field(default=False)
+    origin_location_id: str = field(default=None)
+    origin_location_name: str = field(default=None)
+    destination_location_id: str = field(default=None)
+    destination_location_name: str = field(default=None)
