@@ -91,6 +91,10 @@ class TransactionSchema(CamelCaseSchema):
 	origin_pallets_required = fields.Boolean(allow_none=True)
 	destination_pallets_required = fields.Boolean(allow_none=True)
 	hazmat = fields.Boolean(allow_none=True)
+	origin_location_id = fields.String(allow_none=None)
+	origin_location_name = fields.String(allow_none=None)
+	destination_location_id = fields.String(allow_none=None)
+	destination_location_name = fields.String(allow_none=None)
 
 	@post_load
 	def classify(self, data, **kwargs):
